@@ -155,9 +155,12 @@ def bias_estimation(regions_list, params):
 				for read in read_lst_strand[strand]:
 					if read.cigartuples is not None:
 						first_tuple = read.cigartuples[-1] if read.is_reverse else read.cigartuples[0]
-						if first_tuple[0] == 0 and first_tuple[1] > params.k_flank + max(np.abs(params.read_shift)):	#Only include non-clipped reads
+						if first_tuple[0] == 0:	#Only include non-clipped reads
 							read_per_pos[read.cutsite] = read_per_pos.get(read.cutsite, []) + [read]
 
+				n_reads_kept = sum([len(l) for l in read_per_pos.values()]) #total number of reads across all cutsites in dict
+				logger.spam("Region: {0} ({1}) | Number of positions cut: {2} | Sum of read_per_pos: {3}".format(region.tup(), strand, len(read_per_pos), n_reads_kept))
+
 				#Get kmer for each position
 				for cutsite in read_per_pos:
 					if cutsite > region.start and cutsite < region.end:  	#only reads within borders
