@@ -129,7 +129,7 @@ class MotifList(list):
 			bg = None
 			
 			#Read meme input line by line
-			lines = content.split("\n")
+			lines = content.split("\n") + [""] #make sure file ends with empty line
 			for line in lines:
 
 				### Header content ###
@@ -245,6 +245,12 @@ class MotifList(list):
 		else:
 			sys.exit("Error when reading motifs from {0}! File format: {1}".format(path, file_format))
 
+		#Check if any motifs have length 0 (length == None)
+		for motif in self:
+			if motif.length == None:
+
+				sys.exit("ERROR: No matrix could be read for motif '{0} {1}' - please check the format of the input motif file.".format(motif.id, motif.name))
+
 		#Final changes to motifs
 		for motif in self:
 
@@ -490,7 +496,7 @@ class MotifList(list):
 
 		from gimmemotifs.comparison import MotifComparer
 
-		self = [motif.get_gimmemotifs() if motif.gimme_obj is None else motif for motif in self]	#fill in gimme_obj if it is not found
+		self = [motif.get_gimmemotif() if motif.gimme_obj is None else motif for motif in self]	#fill in gimme_obj if it is not found
 		motif_list = [motif.gimme_obj for motif in self]	#list of gimmemotif objects
 
 		if len(motif_list) > 1:
@@ -835,8 +841,13 @@ class OneMotif:
 			row = [self.counts[letter][pos_id] for letter in range(len(self.bases))] 	# each row represents one position in motif ( A C G T )
 			motif_rows.append(row)
 
-		self.gimme_obj = Motif(motif_rows) 	# generate gimmemotif motif instance
+		# generate gimmemotif motif instance
+		self.gimme_obj = Motif()
+  
+		# populate empty object
 		self.gimme_obj.id = self.id + " " + self.name
+		self.gimme_obj.pfm = motif_rows
+		self.gimme_obj.pwm = self.gimme_obj.pfm_to_pwm(motif_rows)
 
 		return(self)
 		
@@ -881,7 +892,7 @@ class OneMotif:
 
 		return(self)
 
-	def get_threshold(self, pvalue):
+	def get_threshold(self, pvalue=0.0001):
 		""" Get threshold for moods scanning """
 
 		if self.pssm is None:
@@ -934,8 +945,14 @@ class OneMotif:
 
 		return(self)
 
-	def logo_to_file(self, filename):
-		""" Plots the motif to pdf/png/jpg file """
+	def logo_to_file(self, filename, ylim=(0, 2)):
+		"""
+		Plots the motif to pdf/png/jpg file
+
+		Parameters:
+			filename (string): Name of the output file.
+			ylim (tuple, list or string): Forwarded to create_logo().
+		"""
 
 		ext = os.path.splitext(filename)[-1]
 
@@ -947,7 +964,7 @@ class OneMotif:
 			warnings.warn("The 'jpg' format is not supported for motif image. Type is set to 'png'")
 
 		#self.gimme_obj.to_img(filename)	
-		logo = self.create_logo()	#returns a logo object
+		logo = self.create_logo(ylim=ylim)	#returns a logo object
 		logo.fig.savefig(filename)
 		plt.close(logo.fig)
 
@@ -963,8 +980,18 @@ class OneMotif:
 
 		return(self)
 
-	def create_logo(self, ax = None, motif_len=None):
-		""" Creates motif logo in axes object """
+	def create_logo(self, ax = None, motif_len=None, ylim=(0, 2)):
+		"""
+		Creates motif logo in axes object
+
+		Parameters:
+			ax (matplitlib.axes): Axes object, where to logo should live. Default = None
+			motif_len (int): Number of bases displayed in plot. Default length of motif (all).
+			ylim (tuple, list or string): Either 'auto' to autoscale yaxis to max or tuple/ list of parameters (*args) to matplotlib.axes.Axes.set_ylim. Default 0 to 2.
+
+		Returns:
+			logomaker.Logo object
+		"""
 
 		# convert to pandas dataframe
 		df = pd.DataFrame(self.counts).transpose()
@@ -977,14 +1004,24 @@ class OneMotif:
 		info_df = logomaker.transform_matrix(df, from_type="counts", to_type="information")
 		self.info_df = info_df
 
+		# compute y-axis limits and ticks
+		ylim = (0, info_df.sum(axis=1).max()) if ylim == "auto" else ylim
+		# validate ylim
+		if not isinstance(ylim, (list, tuple)):
+			raise ValueError("Parameter ylim should be either 'auto' or a list/ tuple of arguments to matplotlib.axes.Axes.set_ylim.")
+		tick_num = 4
+		step = (ylim[1] - ylim[0]) / tick_num
+		yticks = [ylim[0]+step*i for i in range(tick_num + 1)]
+
 		# create Logo object
 		logo = logomaker.Logo(info_df, ax = ax)
 
 		# style
 		logo.style_xticks(rotation=0, fmt='%d', anchor=0)
-		logo.ax.set_ylim(0, 2)
+		logo.ax.set_ylim(*ylim)
 		logo.ax.set_xlim(-0.5, motif_len-0.5)
-		logo.ax.set_yticks([0, 0.5, 1, 1.5, 2], minor=False)
+		logo.ax.set_yticks(yticks, minor=False)
+		logo.ax.set_xticklabels(range(1,motif_len+1)) #0 -> 1-based coordinates
 		logo.style_spines(visible=False)
 		logo.style_spines(spines=['left', 'bottom'], visible=True)
 		logo.ax.xaxis.set_ticks_position('none')
